@@ -277,6 +277,7 @@ class SecurePDPConfig:
     client_secret: str
     token_url: str
     scope: str = ""
+    resource: Optional[str] = None  # RFC 8707 - Resource Indicators for OAuth 2.0 (preferred)
 
     # Advanced PEP configuration
     enable_constraints: bool = True
@@ -451,6 +452,7 @@ class SecureEnhancedPDP:
         client_secret: str,
         token_url: str,
         scope: str = "",
+        resource: Optional[str] = None,
         config: SecurePDPConfig = None,
     ):
         if not HTTPX_AVAILABLE:
@@ -462,8 +464,10 @@ class SecureEnhancedPDP:
         if config:
             self.config = config
         else:
+            # RFC 8707 resource support: prefer resource parameter, fallback to env var
+            resolved_resource = resource or os.getenv("PDP_TOKEN_RESOURCE") or os.getenv("PDP_TOKEN_AUDIENCE")
             self.config = SecurePDPConfig(
-                base_url, client_id, client_secret, token_url, scope
+                base_url, client_id, client_secret, token_url, scope, resolved_resource
             )
 
         self.logger = logging.getLogger(__name__)
